@@ -2,35 +2,8 @@
 #
 # Univention Portal
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2020-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2020-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 #
 
 import importlib
@@ -55,8 +28,8 @@ class Reloader(metaclass=Plugin):
     for caches.
 
     `refresh`: In fact the only method. Gets a "reason" so that it can
-            decide that a refresh is not necessary. If it was necessary, it
-            should return True
+        decide that a refresh is not necessary. If it was necessary, it
+        should return True
 
     A reason "force" should be treated as very important.
     If the reloader refreshed the content, the overlying cache will reload
@@ -75,7 +48,7 @@ class MtimeBasedLazyFileReloader(Reloader):
     the content and writes it into the file.
 
     cache_file:
-            Filename this object is responsible for
+        Filename this object is responsible for
     """
 
     def __init__(self, cache_file):
@@ -131,9 +104,9 @@ class PortalReloaderUDM(MtimeBasedLazyFileReloader):
     portal object using UDM. Reacts on reasons like "ldap:portal:<correct_dn>".
 
     portal_dn:
-            DN of the portals/portal object
+        DN of the portals/portal object
     cache_file:
-            Filename this object is responsible for
+        Filename this object is responsible for
     """
 
     def __init__(self, portal_dn, cache_file):
@@ -331,21 +304,23 @@ class GroupsReloaderLDAP(MtimeBasedLazyFileReloader):
     Specialized class that reloads a cache file with the content of group object
     in LDAP. Reacts on the reason "ldap:group".
 
-    .. warnings:: As of 4.0.7-8 we use univention-group-membership-cache to
-    obtain groups user belongs to; but we cannot change the constructor kwargs
-    because customers may have added entries to
-    /usr/share/univention-portal/portals.json that still uses them.
+    .. warning::
+
+        As of 4.0.7-8 we use univention-group-membership-cache to
+        obtain groups user belongs to; but we cannot change the constructor kwargs
+        because customers may have added entries to
+        /usr/share/univention-portal/portals.json that still uses them.
 
     ldap_uri:
-            URI for the LDAP connection, e.g. "ldap://ucs:7369"
+        URI for the LDAP connection, e.g. "ldap://ucs:7369"
     binddn:
-            The bind dn for the connection, e.g. "cn=ucs,cn=computers,..."
+        The bind dn for the connection, e.g. "cn=ucs,cn=computers,..."
     password_file:
-            Filename that holds the password for the binddn, e.g. "/etc/machine.secret"
+        Filename that holds the password for the binddn, e.g. "/etc/machine.secret"
     ldap_base:
-            Base in which the groups are searched in. E.g., "dc=base,dc=com" or "cn=groups,ou=OU1,dc=base,dc=com"
+        Base in which the groups are searched in. E.g., "dc=base,dc=com" or "cn=groups,ou=OU1,dc=base,dc=com"
     cache_file:
-            Filename this object is responsible for
+        Filename this object is responsible for
     """
 
     def __init__(self, ldap_uri, binddn, password_file, ldap_base, cache_file):
